A Command line tool to sort a images and mp4 files 
into a date-wise created folder.

## Usage

### Sort

`$ sitf Directory`

*Note: Dirtectory path containing spaces should be quoteted inside double quotes```sitf "C:\Example Folder"```*

### Help

`$ sitf --help`

## Install
`$ pip install sitf`

Or, update to latest version with:

`$ pip install sitf --upgrade`
